@@ -1,3 +1,5 @@
+#![allow(clippy::redundant_allocation)]
+
 use self::static_check::should_use_create_element;
 use crate::refresh::options::{deserialize_refresh, RefreshOptions};
 use dashmap::DashMap;
@@ -303,7 +305,7 @@ impl JsxDirectives {
                         Some("@jsxFrag") => match val {
                             Some(src) => {
                                 res.pragma_frag = Some(parse_expr_for_jsx(
-                                    &cm,
+                                    cm,
                                     "module-jsx-pragma-frag",
                                     src.to_string(),
                                     top_level_mark,
@@ -314,7 +316,7 @@ impl JsxDirectives {
                         Some("@jsx") => match val {
                             Some(src) => {
                                 res.pragma = Some(parse_expr_for_jsx(
-                                    &cm,
+                                    cm,
                                     "module-jsx-pragma",
                                     src.to_string(),
                                     top_level_mark,
@@ -558,7 +560,7 @@ where
                                     };
 
                                     // TODO: Check if `i` is a valid identifier.
-                                    let key = if i.sym.contains("-") {
+                                    let key = if i.sym.contains('-') {
                                         PropName::Str(Str {
                                             span: i.span,
                                             value: i.sym,
@@ -656,7 +658,9 @@ where
                 self.top_level_node = top_level_node;
 
                 let args = once(name.as_arg()).chain(once(props_obj.as_arg()));
-                let args = if self.development {
+                let args = if use_create_element {
+                    args.collect()
+                } else if self.development {
                     // set undefined literal to key if key is None
                     let key = match key {
                         Some(key) => key,
@@ -817,10 +821,9 @@ where
             return self.fold_attrs_for_next_classic(attrs);
         }
 
-        let is_complex = attrs.iter().any(|a| match *a {
-            JSXAttrOrSpread::SpreadElement(..) => true,
-            _ => false,
-        });
+        let is_complex = attrs
+            .iter()
+            .any(|a| matches!(*a, JSXAttrOrSpread::SpreadElement(..)));
 
         if is_complex {
             let mut args = vec![];
@@ -1264,9 +1267,9 @@ fn jsx_text_to_str(t: JsWord) -> JsWord {
     static SPACE_END: Lazy<Regex> = Lazy::new(|| Regex::new("[ ]+$").unwrap());
     let mut buf = String::new();
     let replaced = t.replace('\t', " ");
-    let lines: Vec<&str> = replaced.lines().collect();
-    for (is_last, (i, line)) in lines.into_iter().enumerate().identify_last() {
-        if line.len() == 0 {
+
+    for (is_last, (i, line)) in replaced.lines().enumerate().identify_last() {
+        if line.is_empty() {
             continue;
         }
         let line = Cow::from(line);
@@ -1283,8 +1286,8 @@ fn jsx_text_to_str(t: JsWord) -> JsWord {
         if line.len() == 0 {
             continue;
         }
-        if i != 0 && buf.len() != 0 {
-            buf.push_str(" ")
+        if i != 0 && !buf.is_empty() {
+            buf.push(' ')
         }
         buf.push_str(&line);
     }
@@ -1346,7 +1349,7 @@ fn transform_jsx_attr_str(v: &str) -> String {
             '\0' => buf.push_str("\\x00"),
 
             '\'' if single_quote => buf.push_str("\\'"),
-            '"' if !single_quote => buf.push_str("\""),
+            '"' if !single_quote => buf.push('\"'),
 
             '\x01'..='\x0f' | '\x10'..='\x1f' => {
                 buf.push(c);
